Struct slog_json::JsonBuilder
source · pub struct JsonBuilder<W: Write> { /* private fields */ }Expand description
Json Drain builder
Create with Json::new.
Implementations
sourceimpl<W> JsonBuilder<W>where
W: Write,
impl<W> JsonBuilder<W>where
W: Write,
sourcepub fn set_newlines(self, enabled: bool) -> Self
pub fn set_newlines(self, enabled: bool) -> Self
Set writing a newline after every log record
sourcepub fn set_flush(self, enabled: bool) -> Self
pub fn set_flush(self, enabled: bool) -> Self
Enable flushing of the io::Write after every log record
sourcepub fn set_pretty(self, enabled: bool) -> Self
pub fn set_pretty(self, enabled: bool) -> Self
Set whether or not pretty formatted logging should be used
sourcepub fn add_key_value<T>(self, value: OwnedKV<T>) -> Selfwhere
T: SendSyncRefUnwindSafeKV + 'static,
pub fn add_key_value<T>(self, value: OwnedKV<T>) -> Selfwhere
T: SendSyncRefUnwindSafeKV + 'static,
Add custom values to be printed with this formatter
sourcepub fn add_default_keys(self) -> Self
pub fn add_default_keys(self) -> Self
Add default key-values:
ts- timestamplevel- record logging level namemsg- msg - formatted logging message