Struct slog_json::JsonBuilder [] [src]

pub struct JsonBuilder {
    // some fields omitted
}

Json formatter builder

Create with Json::build.

Methods

impl JsonBuilder
[src]

Build Json format

This consumes the builder.

Set writing a newline after ever log record

Add custom values to be printed with this formatter

Add custom values to be printed with this formatter