Struct slog_json::JsonBuilder
[−]
[src]
pub struct JsonBuilder {
// some fields omitted
}Json formatter builder
Create with Json::build.
Methods
impl JsonBuilder[src]
fn build(self) -> Json
Build Json format
This consumes the builder.
fn set_newlines(&mut self, enabled: bool) -> &mut Self
Set writing a newline after ever log record
fn add_key_values(&mut self, values: Vec<OwnedKeyValue>) -> &mut Self
Add custom values to be printed with this formatter
fn add_key_value(&mut self, value: OwnedKeyValue) -> &mut Self
Add custom values to be printed with this formatter